"""
XBee package initalization file

By Paul Malmsten, 2010
pmalmsten@gmail.com
"""

from xbee.impl import XBee
